
package Apache2::ASP::ApplicationStateManager::MySQL;

use base 'Apache2::ASP::ApplicationStateManager';

1;# return true:

__END__

=pod

=head1 NAME

Apache2::ASP::ApplicationStateManager::MySQL - MySQL storage for the $Application object

=head1 DESCRIPTION

This package provides a MySQL backend for persisting Application state.

=head1 SEE ALSO

L<Apache2::ASP::ApplicationStateManager>

=head1 BUGS

It's possible that some bugs have found their way into this release.

Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Apache2-ASP> to submit bug reports.

=head1 HOMEPAGE

Please visit the Apache2::ASP homepage at L<http://www.devstack.com/> to see examples
of Apache2::ASP in action.

=head1 AUTHOR

John Drago L<mailto:jdrago_999@yahoo.com>

=head1 COPYRIGHT AND LICENSE

Copyright 2007 John Drago, All rights reserved.

This software is free software.  It may be used and distributed under the
same terms as Perl itself.

=cut
